summaryrefslogtreecommitdiff
path: root/libpod/runtime.go
diff options
context:
space:
mode:
Diffstat (limited to 'libpod/runtime.go')
-rw-r--r--libpod/runtime.go20
1 files changed, 10 insertions, 10 deletions
diff --git a/libpod/runtime.go b/libpod/runtime.go
index 7e006b1fc..87b2d10a2 100644
--- a/libpod/runtime.go
+++ b/libpod/runtime.go
@@ -57,10 +57,10 @@ const (
// place of the configuration file pointed to by ConfigPath.
OverrideConfigPath = "/etc/containers/libpod.conf"
- // DefaultPauseImage to use for pause container
- DefaultPauseImage = "k8s.gcr.io/pause:3.1"
- // DefaultPauseCommand to be run in a pause container
- DefaultPauseCommand = "/pause"
+ // DefaultInfraImage to use for infra container
+ DefaultInfraImage = "k8s.gcr.io/pause:3.1"
+ // DefaultInfraCommand to be run in an infra container
+ DefaultInfraCommand = "/pause"
)
// A RuntimeOption is a functional option which alters the Runtime created by
@@ -157,10 +157,10 @@ type RuntimeConfig struct {
// and all containers and pods will be visible.
// The default namespace is "".
Namespace string `toml:"namespace,omitempty"`
- // PauseImage is the image a pod pause container will use to manage namespaces
- PauseImage string `toml:"pause_image"`
- // PauseCommand is the command run to start up a pod pause container
- PauseCommand string `toml:"pause_command"`
+ // InfraImage is the image a pod infra container will use to manage namespaces
+ InfraImage string `toml:"infra_image"`
+ // InfraCommand is the command run to start up a pod infra container
+ InfraCommand string `toml:"infra_command"`
}
var (
@@ -195,8 +195,8 @@ var (
NoPivotRoot: false,
CNIConfigDir: "/etc/cni/net.d/",
CNIPluginDir: []string{"/usr/libexec/cni", "/usr/lib/cni", "/opt/cni/bin"},
- PauseCommand: DefaultPauseCommand,
- PauseImage: DefaultPauseImage,
+ InfraCommand: DefaultInfraCommand,
+ InfraImage: DefaultInfraImage,
}
)